@@ -14,40 +14,46 @@ class ConfigurationCore:
     def __init__(self, config_path=None, config_string=None):
 
         if config_path and config_string:
-            logging.fatal('Please initialize with either config_path or config_string, not both.')
+            logging.fatal(
+                "Please initialize with either config_path or config_string, not both."
+            )
             sys.exit(1)
 
         try:
             if config_string:
-                logging.info('Reading config from provided string.')
+                logging.info("Reading config from provided string.")
                 self.config = yaml.safe_load(config_string)
-                self.config_dir = '.'
+                self.config_dir = "."
             else:  # maybe config_path
-                if 'APP_HOME' in os.environ:
+                if "APP_HOME" in os.environ:
                     # using this env var should be considered unofficial, we need this temporarily
                     # for backwards compatibility. support for it may be removed without notice, do not use it!
-                    config_path = os.path.join(os.environ['APP_HOME'], 'config.yml')
+                    config_path = os.path.join(os.environ["APP_HOME"], "config.yml")
                 elif not config_path:
                     # this case is only meant for using gitlabform as a library
-                    config_path = os.path.join(str(Path.home()), '.gitlabform', 'config.yml')
-                elif config_path in [os.path.join('.', 'config.yml'), 'config.yml']:
+                    config_path = os.path.join(
+                        str(Path.home()), ".gitlabform", "config.yml"
+                    )
+                elif config_path in [os.path.join(".", "config.yml"), "config.yml"]:
                     # provided points to config.yml in the app current working dir
-                    config_path = os.path.join(os.getcwd(), 'config.yml')
+                    config_path = os.path.join(os.getcwd(), "config.yml")
 
                 logging.info("Reading config from file: {}".format(config_path))
 
-                with open(config_path, 'r') as ymlfile:
+                with open(config_path, "r") as ymlfile:
                     self.config = yaml.safe_load(ymlfile)
-                    logging.debug('Config parsed successfully as YAML.')
+                    logging.debug("Config parsed successfully as YAML.")
 
                 # we need config path for accessing files for relative paths
                 self.config_dir = os.path.dirname(config_path)
 
-                if self.config.get('example_config'):
-                    logging.fatal("Example config detected, aborting.\n"
-                                  "Haven't you forgotten to use `-c <config_file` switch?\n"
-                                  "If you created your config based on the example one then please remove "
-                                  "'example_config' key.")
+                if self.config.get("example_config"):
+                    logging.fatal(
+                        "Example config detected, aborting.\n"
+                        "Haven't you forgotten to use `-c <config_file` switch?\n"
+                        "If you created your config based on the example one then please remove "
+                        "'example_config' key."
+                    )
                     sys.exit(1)
 
         except (FileNotFoundError, IOError):
@@ -77,7 +83,7 @@ class ConfigurationCore:
 
         :return: element from YAML file (dict, array, string...)
         """
-        tokens = path.split('|')
+        tokens = path.split("|")
         current = self.config
 
         try:
